
# Slot: close match


a list of terms from different schemas or terminology systems that have a semantically similar but not strictly equivalent, broader, or narrower meaning. Such terms often describe the same general concept from different ontological perspectives (e.g. drug as a type of chemical entity versus drug as a type of role borne by a chemical entity).

URI: [biolink:close_match](https://w3id.org/biolink/vocab/close_match)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [exact match](exact_match.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | skos:closeMatch |
|  | | SEMMEDDB:SAME_AS |
|  | | SEMMEDDB:same_as |
| **Narrow Mappings:** | | CHEBI:is_enantiomer_of |
|  | | CHEBI:is_tautomer_of |
|  | | MEDDRA:classified_as |
|  | | OBO:xref |
|  | | oboformat:xref |
|  | | RXNORM:has_quantified_form |
|  | | UMLS:SY |

